<h1 align="center">
  <br>
  <a href="https://discord.gg/wMB7H9Fp"><img src="https://cdn.discordapp.com/icons/873910232072466432/a07b47688fe729eae554b2730534d5d5.png?size=128" width="150"></a>
  <br>
</h1>

## More Info About Use -> [Pysc Overall Discord](https://discord.gg/wMB7H9Fp)

### What is this lib?
Python API to easily connect Amino servers

### How to install?
`pip install SAmino`
- **FOCUS!:** type `SAmino` **Not** `Amino`

### API Reference documentation
Soon...

Powered By [S-Amino](http://aminoapps.com/c/S-Aminos) Community!
SirLez, A7rf, Texaz, Bovonos
